//$Id: form-prop.h,v 1.9 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_FORM_PROP_H
#define GUIKACHU_FORM_EDITOR_FORM_PROP_H

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class FormProperties;
	}
    }
}

#include "form-res.h"

#include <string>
#include <gtk--/widget.h>

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class FormProperties: public SigC::Object
	    {

		Resources::Form *res;
	    
		/* Property editor */
		Gtk::Widget       *property_editor;
	    public:
		FormProperties (Resources::Form *res);
		~FormProperties ();
		Gtk::Widget *get_editor ();
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_FORM_PROP_H */
